==> kdepim-4.4.10.tar.xz: kdepim-4.4.10/blogilo/src/constants.h <==
/*
    This file is part of Blogilo, A KDE Blogging Client

    Copyright (C) 2008-2009 Mehrdad Momeny <mehrdad.momeny@gmail.com>
    Copyright (C) 2008-2009 Golnaz Nilieh <g382nilieh@gmail.com>

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2 of
    the License or (at your option) version 3 or any later version
    accepted by the membership of KDE e.V. (or its successor approved
    by the membership of KDE e.V.), which shall act as a proxy
    defined in Section 14 of version 3 of the license.


    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, see http://www.gnu.org/licenses/
*/

#ifndef CONSTANTS_H
#define CONSTANTS_H

#include <kstandarddirs.h>

/**
Constants.
 @author Mehrdad Momeny <mehrdad.momeny@gmail.com>
 @author Golnaz Nilieh <g382nilieh@gmail.com>
 */

static const char VERSION[] = "1.0.1";
static const char APPNAME[] = "Blogilo";
#define DATA_DIR KStandardDirs::locateLocal("data", "blogilo/")
#define CONF_DB QString(DATA_DIR)+QString("/blogilo.db")
#define CACHED_MEDIA_DIR KStandardDirs::locateLocal("cache", "blogilo/media/", true)
static const int STATUSTIMEOUT = 5000;


#endif

==> kdepim-15.08.1.tar.xz: kdepim-15.08.1/blogilo/src/constants.h <==
/*
    This file is part of Blogilo, A KDE Blogging Client

    Copyright (C) 2008-2010 Mehrdad Momeny <mehrdad.momeny@gmail.com>
    Copyright (C) 2008-2010 Golnaz Nilieh <g382nilieh@gmail.com>

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2 of
    the License or (at your option) version 3 or any later version
    accepted by the membership of KDE e.V. (or its successor approved
    by the membership of KDE e.V.), which shall act as a proxy
    defined in Section 14 of version 3 of the license.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, see http://www.gnu.org/licenses/
*/

#ifndef CONSTANTS_H
#define CONSTANTS_H

#include <QStandardPaths>

/**
Constants.
 @author Mehrdad Momeny <mehrdad.momeny@gmail.com>
 @author Golnaz Nilieh <g382nilieh@gmail.com>
 */

static const QString VERSION = QStringLiteral("1.2");
static const char APPNAME[] = "Blogilo";
#define DATA_DIR QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1String("/blogilo/")
#define CONF_DB DATA_DIR+QLatin1String("/blogilo.db")
static const int STATUSTIMEOUT = 5000;

#endif
